#[repr(u8)]pub enum Privdefena {
Enable = 0,
Disable = 1,
}Variants
Enable = 0
Disables the default memory map. Any instruction or data access that does not access a defined region faults.
Disable = 1
Enables the default memory map as a background region for privileged accesses.
Implementations
Sourceimpl Privdefena
impl Privdefena